sample_test_with_naarad_run_tests_in_parallel_20150111_233613

### sample_config2 : test2

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 5.15797495842 sec | 5.15940594673 sec

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
sample-perf | qps | mean lt 10.0 | None
sample-perf | latency | p99 lt 300.0 | None
sample-perf | latency | p50 lt 250.0 | None
sample-perf | latency | mean lt 125.0 | None